@@ -3,7 +3,7 @@
 """
 RDF triple store classes.
 
-Copyright (C) 2006 Paul Boddie <paul@boddie.org.uk>
+Copyright (C) 2006, 2007 Paul Boddie <paul@boddie.org.uk>
 
 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Lesser General Public
@@ -276,12 +276,18 @@ class TripleStore:
             # Add the values in the list as a set from which one of the values
             # must match the stated column's value.
 
-            conditions.append("%s in (%s)" % (
-                self._column(column_name, index),
-                ", ".join(["?"] * len(value))
-                ))
-            for v in value:
-                values.append(unicode(v))
+            if value:
+                conditions.append("%s in (%s)" % (
+                    self._column(column_name, index),
+                    ", ".join(["?"] * len(value))
+                    ))
+                for v in value:
+                    values.append(unicode(v))
+            else:
+                conditions.append("%s <> %s" % (
+                    self._column(column_name, index),
+                    self._column(column_name, index)
+                    ))
 
         # Process a single value.
 
